Python toolbox for working with geographical positions defined by latitude and
longitude. The position is essentially a python object, which can parse different
formats from strings and output it in several typical formats. Two positions can
be subtracted to easily calculate the distance between two points.
The toolbox includes a simple gui to convert strings, to compute the distance 
between two positions, plot them on a simple map and to output as a string in
a user choosable format.
